# 作者：Xiaoqiang
# 微信公众号：XiaoqiangClub
# GitHub：https://github.com/xiaoqiangclub
# 邮箱：xiaoqiangclub@hotmail.com
# 创建时间：2025-01-20 10:00:00
# 文件描述：版本信息
# 文件路径：msimg/version.py

__version__ = "0.0.4"
__author__ = "Xiaoqiang"
__email__ = "xiaoqiangclub@hotmail.com"
